# onnx.compose

```{eval-rst}
.. currentmodule:: onnx.compose
```

```{eval-rst}
.. autosummary::

    merge_graphs
    merge_models
```

## merge_graphs

```{eval-rst}
.. autofunction:: onnx.compose.merge_graphs
```

## merge_models

```{eval-rst}
.. autofunction:: onnx.compose.merge_models
```

## prefix

```{eval-rst}
.. autofunction:: onnx.compose.add_prefix_graph
```

```{eval-rst}
.. autofunction:: onnx.compose.add_prefix
```

## dimension

```{eval-rst}
.. autofunction:: onnx.compose.expand_out_dim
```

```{eval-rst}
.. autofunction:: onnx.compose.expand_out_dim_graph
```
